@@ -100,7 +100,7 @@ class sync_client:
         :return: An RTFMResponse object
         :rtype: RTFMResponse
         """
-        with requests.get(f"{location.removesuffix('/')}/objects.inv") as resp:
+        with requests.get(f"{location.rstrip('/')}/objects.inv") as resp:
             if resp.status == 404:
                 raise InvalidRtfmLibrary(location)
 
@@ -252,11 +252,11 @@ class sync_client:
         if response.reason.startswith("Tag"):
             raise TagAlreadyAssigned(response.reason)
 
-    def homepage(self, links: dict[str, str]):
+    def homepage(self, links: typing.Dict[str, str]):
         """Add links to your homepage, which can be viewed at https://idevision.net/homepage?user=YOUR_USERNAME
 
         :param links: A dictionary of str, str
-        :type links: dict[str, str]
+        :type links: typing.Dict[str, str]
         :return: True if success
         :rtype: bool
         """
